@@ -67,6 +67,9 @@ G_LOCK_DEFINE_STATIC (mime_mutex);
 /**
  * gnome_vfs_mime_shutdown:
  *
+ * Deprecated: This function doesn't have to be called as the
+ * operating system automatically cleans up resources when exiting.
+ *
  * Unload the MIME database from memory.
  **/
 
@@ -235,9 +238,11 @@ _gnome_vfs_get_mime_type_internal (GnomeVFSMimeSniffBuffer *buffer, const char *
 		if (result == NULL || result == XDG_MIME_TYPE_UNKNOWN) {
 			if (_gnome_vfs_sniff_buffer_looks_like_text (buffer)) {
 				/* Text file -- treat extensions as a more 
-				 * accurate source of type information.
+				 * accurate source of type information BUT _only_ if
+				 * the extension is a subtype of text/plain.
 				 */
-				if ((fn_result != NULL) && (fn_result != XDG_MIME_TYPE_UNKNOWN)) {
+				if ((fn_result != NULL) && (fn_result != XDG_MIME_TYPE_UNKNOWN) &&
+				    xdg_mime_mime_type_subclass (fn_result, "text/plain")) {
 					return fn_result;
 				}
 
@@ -249,7 +254,7 @@ _gnome_vfs_get_mime_type_internal (GnomeVFSMimeSniffBuffer *buffer, const char *
 			}
 		}
 	}
-	
+
 	if (use_suffix &&
 	    (result == NULL || result == XDG_MIME_TYPE_UNKNOWN)) {
 		/* No type recognized -- fall back on extensions. */
@@ -481,6 +486,8 @@ gnome_vfs_get_mime_type_from_uri (GnomeVFSURI *uri)
  * Tries to guess the mime type of the file @uri by
  * checking the file data using the magic patterns. Does not handle text files properly
  *
+ * Deprecated:
+ *
  * Returns the mime-type for this filename.
  */
 const char *
